==> nextcloud-app-contacts-7.3.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/oc.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalhs",
    "All contacts" : "Totes los contactes",
    "Contacts" : "Contactes",
    "Loading …" : "Cargament…",
    "General settings" : "Paramètres generals",
    "Rename" : "Renomenar",
    "Send email" : "Enviar email",
    "Delete" : "Suprimir",
    "Copy link" : "Copiar lo ligam",
    "Download" : "Telecargar",
    "can edit" : "pòt modificar",
    "Add" : "Ajustar",
    "First name" : "Prenom",
    "Last name" : "Nom",
    "Display name" : "Nom afichat",
    "Save" : "Enregistrar",
    "Cancel" : "Anullar",
    "Invalid image" : "Imatge invalid",
    "Name" : "Nom",
    "Title" : "Títol",
    "Company" : "Entrepresa",
    "Groups" : "Gropes",
    "Search contacts …" : "Cercar pels contactes…",
    "No results" : "Cap de resultat",
    "Pending" : "En espèra",
    "None" : "Pas cap",
    "New contact" : "Contacte novèl",
    "Close" : "Tampar",
    "Import" : "Importar",
    "Not grouped" : "Pas gropats",
    "Recently contacted" : "Contactat recentament",
    "User" : "User",
    "Group" : "Grop",
    "Email" : "Adreça corrièl",
    "Contact" : "Contacte",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Additional names" : "Noms suplementaris",
    "Nickname" : "Escais",
    "Notes" : "Nòtas",
    "Website" : "Site web",
    "Location" : "Emplaçament",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Domicili",
    "Work" : "Professional(a)",
    "Other" : "Autre",
    "Address" : "Adreça",
    "City" : "Vila",
    "State or province" : "Estat o region",
    "Postal code" : "Còde postal",
    "Country" : "País",
    "Birthday" : "Anniversari",
    "Anniversary" : "Anniversari",
    "Instant messaging" : "Messatjariá instantanèa",
    "Phone" : "Telefòn",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Pager" : "Messatgièr",
    "Voice" : "Votz",
    "Relative" : "Relatiu",
    "Unknown" : "Desconegut",
    "Spoken languages" : "Lengas parladas"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-contacts-8.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/oc.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalhs",
    "All contacts" : "Totes los contactes",
    "Contacts" : "Contactes",
    "General settings" : "Paramètres generals",
    "Rename" : "Renomenar",
    "Send email" : "Enviar email",
    "Delete" : "Suprimir",
    "Copy link" : "Copiar lo ligam",
    "Download" : "Telecargar",
    "can edit" : "pòt modificar",
    "Add" : "Ajustar",
    "First name" : "Prenom",
    "Last name" : "Nom",
    "Display name" : "Nom afichat",
    "Save" : "Enregistrar",
    "Cancel" : "Anullar",
    "Invalid image" : "Imatge invalid",
    "Name" : "Nom",
    "Title" : "Títol",
    "Company" : "Entrepresa",
    "Groups" : "Gropes",
    "No results" : "Cap de resultat",
    "Pending" : "En espèra",
    "None" : "Pas cap",
    "New contact" : "Contacte novèl",
    "Close" : "Tampar",
    "Import" : "Importar",
    "Not grouped" : "Pas gropats",
    "Recently contacted" : "Contactat recentament",
    "User" : "User",
    "Group" : "Grop",
    "Email" : "Adreça corrièl",
    "Contact" : "Contacte",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Additional names" : "Noms suplementaris",
    "Nickname" : "Escais",
    "Notes" : "Nòtas",
    "Website" : "Site web",
    "Location" : "Emplaçament",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Domicili",
    "Work" : "Professional(a)",
    "Other" : "Autre",
    "Address" : "Adreça",
    "City" : "Vila",
    "State or province" : "Estat o region",
    "Postal code" : "Còde postal",
    "Country" : "País",
    "Birthday" : "Anniversari",
    "Anniversary" : "Anniversari",
    "Instant messaging" : "Messatjariá instantanèa",
    "Phone" : "Telefòn",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Pager" : "Messatgièr",
    "Voice" : "Votz",
    "Relative" : "Relatiu",
    "Unknown" : "Desconegut",
    "Spoken languages" : "Lengas parladas",
    "Loading …" : "Cargament…",
    "Search contacts …" : "Cercar pels contactes…"
},
"nplurals=2; plural=(n > 1);");
